@@ -17,7 +17,7 @@ def create_dask_df(database=None,
 
     storage_client = storage.Client()
     bucket = storage_client.bucket(gcs_bucket)
-    blob = bucket.blob(f'schemas/{table}-dask-schema.json')
+    blob = bucket.blob(f'schemas/{database}-{table}-dask-schema.json')
     dt_blob = blob.download_as_text()
     data_types = json.loads(dt_blob)
 
